@@ -27,6 +27,14 @@
 --
 --
 -- $Log: compress_sparse.c,v $
+-- Revision 1.20  2007/08/10 00:03:35  jsedwards
+-- Removed defintion of _LARGEFILE64_SOURCE, now using _FILE_OFFSET_BITS=64.
+-- Also removed using O_LARGEFILE from open call.
+--
+-- Revision 1.19  2007/08/02 18:51:42  jsedwards
+-- Change to use the new index in the chunk_info table to compute the address
+-- of the chunk in disk storage.
+--
 -- Revision 1.18  2007/07/15 18:32:34  jsedwards
 -- Fix screwup on previous checkin (left function bswap_uint32 in).
 --
@@ -117,8 +125,6 @@
 */
 
 
-#define _LARGEFILE64_SOURCE
-
 #include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -165,7 +171,7 @@ int main(int argc, char* argv[])
     uint8 sha1_digest[20];
     int chunk_num;
     uint32 used_chunks;
-    uint32* chunk_index;
+    Chunk_Info* chunk_info;
 
 
     for (i = 0; i < SIZE_COUNTS; i++) counts[i] = 0;
@@ -186,7 +192,7 @@ int main(int argc, char* argv[])
 
     /* Open the storage drive and verify the header info */
 
-    obj_file_desc = open(DEFAULT_FILE, O_RDONLY | O_LARGEFILE);
+    obj_file_desc = open(DEFAULT_FILE, O_RDONLY);
 
     if (obj_file_desc < 0)
     {
@@ -223,14 +229,14 @@ int main(int argc, char* argv[])
 
     assert(used_chunks > 0);
 
-    chunk_index = malloc(used_chunks * sizeof(uint32));
-    assert(chunk_index != NULL);
+    chunk_info = malloc(used_chunks * sizeof(Chunk_Info));
+    assert(chunk_info != NULL);
 
-    bytes_read = read(obj_file_desc, chunk_index, used_chunks * sizeof(uint32));
+    bytes_read = read(obj_file_desc, chunk_info, used_chunks * sizeof(Chunk_Info));
 
-    if (bytes_read != used_chunks * sizeof(uint32))
+    if (bytes_read != used_chunks * sizeof(Chunk_Info))
     {
-	perror("reading chunk index");
+	perror("reading chunk info");
 	exit(1);
     }
 
@@ -240,7 +246,9 @@ int main(int argc, char* argv[])
 	  int i;
 	  for (i = 0; i < used_chunks; i++)
 	  {
-	      chunk_index[i] = byteswap_uint32(chunk_index[i]);
+	      chunk_info[i].ref = byteswap_uint32(chunk_info[i].ref);
+	      chunk_info[i].used = byteswap_uint16(chunk_info[i].used);
+	      chunk_info[i].index = byteswap_uint16(chunk_info[i].index);
 	  }
 	}
 #endif
@@ -284,7 +292,7 @@ int main(int argc, char* argv[])
     // for now we can skip over public blocks because they should always stay the same
     for (chunk_num = 0; chunk_num < used_chunks; chunk_num++)
     {
-	chunk = chunk_block_offset + chunk_num * BLOCKS_IN_CHUNK;
+	chunk = chunk_block_offset + chunk_info[chunk_num].index * BLOCKS_IN_CHUNK;
 
 	if (lseek(obj_file_desc, chunk << 8, SEEK_SET) < 0)
 	{
