@@ -27,6 +27,12 @@
 --
 --
 -- $Log: expand_sparse.c,v $
+-- Revision 1.23  2007/08/10 00:04:06  jsedwards
+-- Removed defintion of _LARGEFILE64_SOURCE, now using _FILE_OFFSET_BITS=64.
+--
+-- Revision 1.22  2007/08/01 01:17:50  jsedwards
+-- Changed to accept 0025 compressed files, as well as 0023 and 0024.
+--
 -- Revision 1.21  2007/07/30 16:04:35  jsedwards
 -- Changed to allow either 0023 or 0024 compressed files (since they are
 -- identical) to be read in.
@@ -132,8 +138,6 @@
 */
 
 
-#define _LARGEFILE64_SOURCE
-
 #include <assert.h>
 #include <fcntl.h>
 #include <stdio.h>
@@ -247,7 +251,7 @@ int main(int argc, char* argv[])
 
     /* Version 0023, 0024 and 0025 archives are identical so allow expanding 0023 or 0024 */
 
-    if (memcmp(&block[4], "0023", 4) == 0 || memcmp(&block[4], "0024", 4) == 0)
+    if (memcmp(&block[4], "0023", 4) == 0 || memcmp(&block[4], "0024", 4) == 0 || memcmp(&block[4], "0025", 4) == 0)
     {
 	fprintf(stderr, "WARNING: compressed file is version 002%c, is compatible.\n", block[7]);
 	printf("WARNING: compressed file is version 002%c, is compatible.\n", block[7]);
