@@ -27,6 +27,45 @@
 --
 --
 -- $Log: objectify.c,v $
+-- Revision 1.137  2007/10/25 03:22:20  jsedwards
+-- Move 'last_ref' to disk_io.c.
+--
+-- Revision 1.136  2007/10/24 14:30:04  jsedwards
+-- Eliminate push and pop security levels.  They are no longer used and to
+-- simplify moving last_ref to disk_io.c.
+--
+-- Revision 1.135  2007/10/19 03:52:55  jsedwards
+-- Halved the range for the medium and high security levels because they are
+-- plus and minus.
+--
+-- Revision 1.134  2007/10/19 03:43:40  jsedwards
+-- Changed the density values for the very low to high security levels, to
+-- spread them out more.
+--
+-- Revision 1.133  2007/10/19 02:11:37  jsedwards
+-- Added defines for 1_in_N security levels and new set_security_level function
+-- that is called by the other security level functions, which sets the chunk
+-- allocation parameters in disk_io.c.
+--
+-- Revision 1.132  2007/10/07 16:35:32  jsedwards
+-- Moved 'last_ref' outside of generate_new_id function so it is global and
+-- can be cleared by the new 'restart_id_generation' function.  Also added
+-- calls to the new 'restart_id_generation' function when security level is
+-- changed.
+--
+-- Revision 1.131  2007/08/12 20:45:00  jsedwards
+-- Change all of the "Encryption Level" stuff to "Security Level" because it
+-- doesn't really change the encryption at all, all it does is change the
+-- randomization of where objects are stored.
+--
+-- Revision 1.130  2007/08/06 02:22:01  jsedwards
+-- Changed values passed to 1_in_N function to 7 for very-low, 19 for low,
+-- 43 for medium, and 113 for high (1_in_N functionality is different now).
+--
+-- Revision 1.129  2007/08/03 01:04:53  jsedwards
+-- Change to allow "High" encryption level to be used and changed low and
+-- medium to skip 32 and 128 instead of 64 and 512.  Made high skip 512.
+--
 -- Revision 1.128  2007/07/30 18:35:02  jsedwards
 -- Added code to save the old file class in case an updated private class
 -- definition has not been created yet.
@@ -745,7 +784,13 @@ ObjRef nwos_public_class_definition_class_ref;
 ObjRef nwos_private_class_definition_class_ref;
 ObjRef nwos_reference_list_class_ref;
 
-static Encryption_Level encryption_level = Encryption_High;
+static Security_Level security_level = Security_None;
+
+#define SECURITY_VERY_LOW_N  7     /* sort of arbitrary, but it's always fun to use prime numbers */
+#define SECURITY_LOW_N      43     /* in this case each digit is represented */
+#define SECURITY_MEDIUM_N  509
+#define SECURITY_HIGH_N   2861
+
 
 #ifndef PUBLIC_MODE
 static uint32 linear_after_first;
@@ -1125,36 +1170,46 @@ Reference_Type nwos_reference_type(ObjRef* ref)
 
 
 
-static Encryption_Level previous_encryption_level;
-
-void nwos_set_encryption_level(Encryption_Level new_level)
+void nwos_set_security_level(Security_Level new_level)
 {
-    assert(Encryption_None <= new_level && new_level <= Encryption_Extreme);
+    bool Security_Not_Set = false;
 
-    encryption_level = new_level;
+    assert(Security_None < new_level && new_level <= Security_Extreme);
 
-    previous_encryption_level = Encryption_None;
-}
+    security_level = new_level;
 
+    switch (new_level)
+    {
+      case Security_Minimal:
+	nwos_set_allocation_parameters( ((USABLE_BLOCKS_PER_CHUNK * 7) / 8), 0, 1);
+	break;
 
-void nwos_push_encryption_level(Encryption_Level new_level)
-{
-    assert(Encryption_None <= new_level && new_level <= Encryption_Extreme);
-    assert(previous_encryption_level == Encryption_None);
+      case Security_Very_Low:
+	nwos_set_allocation_parameters( (USABLE_BLOCKS_PER_CHUNK / SECURITY_VERY_LOW_N), 0, 4);
+	break;
 
-    previous_encryption_level = encryption_level;
+      case Security_Low:
+	nwos_set_allocation_parameters( (USABLE_BLOCKS_PER_CHUNK / SECURITY_LOW_N), 0, 16);
+	break;
 
-    encryption_level = new_level;
-}
+      case Security_Medium:
+	nwos_set_allocation_parameters( (USABLE_BLOCKS_PER_CHUNK / SECURITY_MEDIUM_N), -32, 32);
+	break;
 
+      case Security_High:
+	nwos_set_allocation_parameters( (USABLE_BLOCKS_PER_CHUNK / SECURITY_HIGH_N), -128, 128);
+	break;
 
-void nwos_pop_encryption_level()
-{
-    assert(Encryption_None < previous_encryption_level && previous_encryption_level <= Encryption_Extreme);
+      case Security_Extreme:
+	nwos_set_allocation_parameters(1, -RESERVED_PRIVATE_CHUNKS, RESERVED_PRIVATE_CHUNKS);
+	break;
 
-    encryption_level = previous_encryption_level;
+      default:
+	assert(Security_Not_Set);
+	break;
+    }
 
-    previous_encryption_level = Encryption_None;
+    nwos_restart_id_generation();   /* clear last_ref so this security level starts fresh */
 }
 
 
@@ -1165,43 +1220,48 @@ void nwos_generate_new_id(ObjRef* ref)
 
     assert(nwos_reference_type(ref) == Public_Reference);
 #else
-    bool Cant_Use_Encryption_None = false;
-    bool Encryption_Not_Set = false;
-    static ObjRef last_ref;
+#if 0
+    bool Cant_Use_Security_None = false;
+#endif
+    bool Security_Not_Set = false;
 
-    switch (encryption_level)
+    switch (security_level)
     {
-      case Encryption_None:
-	assert(Cant_Use_Encryption_None);
+#if 0
+      case Security_None:
+	assert(Cant_Use_Security_None);
+	break;
+#endif
+
+      case Security_Minimal:
+	nwos_generate_new_closely_spaced_id(7, ref);
 	break;
 
-      case Encryption_Minimal:
-	nwos_generate_new_closely_spaced_id(&last_ref, 7, ref);
+      case Security_Very_Low:
+	nwos_generate_new_1_in_N_id(SECURITY_VERY_LOW_N, ref);
 	break;
 
-      case Encryption_Very_Low:
-	nwos_generate_new_1_in_N_id(&last_ref, 8, ref);
+      case Security_Low:
+	nwos_generate_new_1_in_N_id(SECURITY_LOW_N, ref);
 	break;
 
-      case Encryption_Low:
-	nwos_generate_new_1_in_N_id(&last_ref, 64, ref);
+      case Security_Medium:
+	nwos_generate_new_1_in_N_id(SECURITY_MEDIUM_N, ref);
 	break;
 
-      case Encryption_Medium:
-	nwos_generate_new_1_in_N_id(&last_ref, 512, ref);
+      case Security_High:
+	nwos_generate_new_1_in_N_id(SECURITY_HIGH_N, ref);
 	break;
 
       default:
-	assert(Encryption_Not_Set);
+	assert(Security_Not_Set);
 	break;
 
-      case Encryption_Extreme:
+      case Security_Extreme:
 	nwos_generate_new_completely_random_id(ref);
 	break;
     }
 
-    copy_reference(&last_ref, ref);
-
     assert(nwos_reference_type(ref) == Private_Reference);
 #endif
 }
