@@ -1,23 +1,61 @@
-/*             This file is part of the New World OS project
+/*
+--             This file is part of the New World OS project
 --                 Copyright (C) 2004-2007  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
 --
--- NWOS is free software;  you can redistribute it and/or modify it under the
--- terms of the GNU General Public License  as published by the Free Software
--- Foundation; either version 2, or (at your option) any later version.  This
--- software is distributed with the hope that it will be useful,  but WITHOUT
--- ANY WARRANTY;  without  even the  implied warranty  of MERCHANTABILITY  or
--- FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License for
--- more  details.  You should have received a copy  of the GNU General Public
--- License along with this package;  see the file LICENSE.  If not, write to:
+--   This program is free software: you can redistribute it and/or modify
+--   it under the terms of the GNU General Public License as published by
+--   the Free Software Foundation, either version 3 of the License, or
+--   (at your option) any later version.
+--
+--   This program is distributed in the hope that it will be useful,
+--   but WITHOUT ANY WARRANTY; without even the implied warranty of
+--   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+--   GNU General Public License for more details.
+--
+--   You should have received a copy of the GNU General Public License
+--   along with this program, in the file LICENSE.  If not, see 
+--   <http://www.gnu.org/licenses/>.
+--
+--   You can also contact me via paper mail at:
+--
+--      QRW Software
+--      P.O. Box 27511
+--      Salt Lake City, UT 84127-0511, USA.
 --
---      Free Software Foundation, Inc.
---      59 Temple Place - Suite 330
---      Boston, MA 02111-1307, USA.
 --
 -- $Log: objectify_private.h,v $
+-- Revision 1.58  2007/10/25 00:48:38  jsedwards
+-- Removed 'last_ref' paramter from nwos_generate_new_closely_spaced_id and
+-- nwos_generate_new_1_in_N_id.
+--
+-- Revision 1.57  2007/10/19 01:48:35  jsedwards
+-- Added external_declaration for the nwos_set_allocation_parameters function.
+--
+-- Revision 1.56  2007/09/15 18:41:53  jsedwards
+-- Added ivec variable to Ref_List_First_Block and Ref_List_Extra_Block
+-- structures.
+--
+-- Revision 1.55  2007/07/31 18:25:28  jsedwards
+-- Changed 'reserved' element of Chunk_Info structure to 'index'.
+--
+-- Revision 1.54  2007/07/28 01:07:02  jsedwards
+-- Left the "nwos_" prefix off update_file_001_object_to_current, added it.
+--
+-- Revision 1.53  2007/07/28 01:03:49  jsedwards
+-- Added external definition for update_file_001_object_to_current.
+--
+-- Revision 1.52  2007/07/07 20:28:40  jsedwards
+-- Move declaration of nwos_log to objectify.h.
+--
+-- Revision 1.51  2007/07/03 00:41:43  jsedwards
+-- Added Chunk_Info structure for chunk info table (previously chunk_index).
+--
+-- Revision 1.50  2007/07/01 19:44:12  jsedwards
+-- Upgrade to GPLv3.
+--
 -- Revision 1.49  2007/06/26 14:32:47  jsedwards
 -- Removed private_generate_new_completely_random_id, now only used in disk_io.c.
 --
@@ -326,6 +364,13 @@ extern uint32 nwos_total_private_blocks;
 extern uint32 nwos_used_public_blocks;
 extern uint32 nwos_used_private_blocks;
 
+
+typedef struct {
+  uint32 ref;
+  uint16 used;
+  uint16 index;
+} Chunk_Info;
+
 extern uint32 nwos_total_private_chunks;
 extern uint32 nwos_used_private_chunks;
 
@@ -340,6 +385,7 @@ typedef struct ref_list_extra_block {
     uint8 checksum[4];
     ObjRef refs[MAX_REFS_IN_SIDECAR];
     ObjRef next_block_ref;
+    uint8 ivec[IVEC_SIZE];
 } Ref_List_Extra_Block;
 
 typedef struct {
@@ -347,6 +393,7 @@ typedef struct {
     ReferenceList list;
     ObjRef refs[MAX_REFS_IN_REF_LIST];
     ObjRef next_block_ref;
+    uint8 ivec[IVEC_SIZE];
 } Ref_List_First_Block;
 
 
@@ -364,8 +411,6 @@ extern void nwos_create_class_definition(char* name_of_class);
 extern void nwos_clone_class_definition(ObjRef* class_to_clone_ref, ObjRef* clone_ref);
 
 
-extern void nwos_log(char* str);
-
 extern void* nwos_malloc(size_t size);
 extern void  nwos_free(void* ptr);
 
@@ -406,9 +451,10 @@ extern char* nwos_public_path;
 extern char* nwos_private_path;
 extern void  nwos_initialize_disk_io(StorageType type, char* path);
 extern void  nwos_terminate_disk_io();
+extern void  nwos_set_allocation_parameters(uint32 density, int32 skip_backward, int32 skip_forward);
 extern void  nwos_allocate_new_chunk(uint32 ref);
-extern void nwos_generate_new_closely_spaced_id(ObjRef* last_ref, int density, ObjRef* new_ref);
-extern void nwos_generate_new_1_in_N_id(ObjRef* last_ref, uint32 n, ObjRef* new_ref);
+extern void nwos_generate_new_closely_spaced_id(int density, ObjRef* new_ref);
+extern void nwos_generate_new_1_in_N_id(uint32 n, ObjRef* new_ref);
 
 extern void nwos_private_create_city(ObjRef* city_class_ref, ObjRef* name_ref, ObjRef* state_ref, ObjRef* city_ref);
 
@@ -416,5 +462,7 @@ extern ObjCreateResult nwos_create_url(char* url, ObjRef* ref);
 
 extern void nwos_create_public_manufacturer(char* brand_name, char* acronym, char* url_list[], ObjRef* ref);
 
+extern void nwos_update_file_001_object_to_current(void* object, size_t size);
+
 #endif
 
